==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/NetworkInsightsAnalysisExplanationRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property destinationCidr
 * @property destinationPrefixListId
 * @property egressOnlyInternetGatewayId
 * @property gatewayId
 * @property instanceId
 * @property natGatewayId
 * @property networkInterfaceId
 * @property origin
 * @property transitGatewayId
 * @property vpcPeeringConnectionId
 */
public data class NetworkInsightsAnalysisExplanationRouteTableRoute(
    public val destinationCidr: String? = null,
    public val destinationPrefixListId: String? = null,
    public val egressOnlyInternetGatewayId: String? = null,
    public val gatewayId: String? = null,
    public val instanceId: String? = null,
    public val natGatewayId: String? = null,
    public val networkInterfaceId: String? = null,
    public val origin: String? = null,
    public val transitGatewayId: String? = null,
    public val vpcPeeringConnectionId: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.NetworkInsightsAnalysisExplanationRouteTableRoute):
            NetworkInsightsAnalysisExplanationRouteTableRoute =
            NetworkInsightsAnalysisExplanationRouteTableRoute(
                destinationCidr = javaType.destinationCidr().map({ args0 -> args0 }).orElse(null),
                destinationPrefixListId = javaType.destinationPrefixListId().map({ args0 -> args0 }).orElse(null),
                egressOnlyInternetGatewayId = javaType.egressOnlyInternetGatewayId().map({ args0 ->
                    args0
                }).orElse(null),
                gatewayId = javaType.gatewayId().map({ args0 -> args0 }).orElse(null),
                instanceId = javaType.instanceId().map({ args0 -> args0 }).orElse(null),
                natGatewayId = javaType.natGatewayId().map({ args0 -> args0 }).orElse(null),
                networkInterfaceId = javaType.networkInterfaceId().map({ args0 -> args0 }).orElse(null),
                origin = javaType.origin().map({ args0 -> args0 }).orElse(null),
                transitGatewayId = javaType.transitGatewayId().map({ args0 -> args0 }).orElse(null),
                vpcPeeringConnectionId = javaType.vpcPeeringConnectionId().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/NetworkInsightsAnalysisExplanationRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property destinationCidr
 * @property destinationPrefixListId
 * @property egressOnlyInternetGatewayId
 * @property gatewayId
 * @property instanceId
 * @property natGatewayId
 * @property networkInterfaceId
 * @property origin
 * @property transitGatewayId
 * @property vpcPeeringConnectionId
 */
public data class NetworkInsightsAnalysisExplanationRouteTableRoute(
    public val destinationCidr: String? = null,
    public val destinationPrefixListId: String? = null,
    public val egressOnlyInternetGatewayId: String? = null,
    public val gatewayId: String? = null,
    public val instanceId: String? = null,
    public val natGatewayId: String? = null,
    public val networkInterfaceId: String? = null,
    public val origin: String? = null,
    public val transitGatewayId: String? = null,
    public val vpcPeeringConnectionId: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.NetworkInsightsAnalysisExplanationRouteTableRoute): NetworkInsightsAnalysisExplanationRouteTableRoute =
            NetworkInsightsAnalysisExplanationRouteTableRoute(
                destinationCidr = javaType.destinationCidr().map({ args0 -> args0 }).orElse(null),
                destinationPrefixListId = javaType.destinationPrefixListId().map({ args0 -> args0 }).orElse(null),
                egressOnlyInternetGatewayId = javaType.egressOnlyInternetGatewayId().map({ args0 ->
                    args0
                }).orElse(null),
                gatewayId = javaType.gatewayId().map({ args0 -> args0 }).orElse(null),
                instanceId = javaType.instanceId().map({ args0 -> args0 }).orElse(null),
                natGatewayId = javaType.natGatewayId().map({ args0 -> args0 }).orElse(null),
                networkInterfaceId = javaType.networkInterfaceId().map({ args0 -> args0 }).orElse(null),
                origin = javaType.origin().map({ args0 -> args0 }).orElse(null),
                transitGatewayId = javaType.transitGatewayId().map({ args0 -> args0 }).orElse(null),
                vpcPeeringConnectionId = javaType.vpcPeeringConnectionId().map({ args0 -> args0 }).orElse(null),
            )
    }
}
